/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.search.experiences.model;

import com.liferay.portal.kernel.bean.AutoEscape;
import com.liferay.portal.kernel.exception.LocaleException;
import com.liferay.portal.kernel.model.BaseModel;
import com.liferay.portal.kernel.model.LocalizedModel;
import com.liferay.portal.kernel.model.MVCCModel;
import com.liferay.portal.kernel.model.ShardedModel;
import com.liferay.portal.kernel.model.StagedAuditedModel;

import java.util.Date;
import java.util.Locale;
import java.util.Map;

import org.osgi.annotation.versioning.ProviderType;

/**
 * The base model interface for the SXPElement service. Represents a row in the &quot;SXPElement&quot; database table, with each column mapped to a property of this class.
 *
 * <p>
 * This interface and its corresponding implementation <code>com.liferay.search.experiences.model.impl.SXPElementModelImpl</code> exist only as a container for the default property accessors generated by ServiceBuilder. Helper methods and all application logic should be put in <code>com.liferay.search.experiences.model.impl.SXPElementImpl</code>.
 * </p>
 *
 * @author Brian Wing Shun Chan
 * @see SXPElement
 * @generated
 */
@ProviderType
public interface SXPElementModel
	extends BaseModel<SXPElement>, LocalizedModel, MVCCModel, ShardedModel,
			StagedAuditedModel {

	/*
	 * NOTE FOR DEVELOPERS:
	 *
	 * Never modify or reference this interface directly. All methods that expect a sxp element model instance should use the {@link SXPElement} interface instead.
	 */

	/**
	 * Returns the primary key of this sxp element.
	 *
	 * @return the primary key of this sxp element
	 */
	public long getPrimaryKey();

	/**
	 * Sets the primary key of this sxp element.
	 *
	 * @param primaryKey the primary key of this sxp element
	 */
	public void setPrimaryKey(long primaryKey);

	/**
	 * Returns the mvcc version of this sxp element.
	 *
	 * @return the mvcc version of this sxp element
	 */
	@Override
	public long getMvccVersion();

	/**
	 * Sets the mvcc version of this sxp element.
	 *
	 * @param mvccVersion the mvcc version of this sxp element
	 */
	@Override
	public void setMvccVersion(long mvccVersion);

	/**
	 * Returns the uuid of this sxp element.
	 *
	 * @return the uuid of this sxp element
	 */
	@AutoEscape
	@Override
	public String getUuid();

	/**
	 * Sets the uuid of this sxp element.
	 *
	 * @param uuid the uuid of this sxp element
	 */
	@Override
	public void setUuid(String uuid);

	/**
	 * Returns the sxp element ID of this sxp element.
	 *
	 * @return the sxp element ID of this sxp element
	 */
	public long getSXPElementId();

	/**
	 * Sets the sxp element ID of this sxp element.
	 *
	 * @param sxpElementId the sxp element ID of this sxp element
	 */
	public void setSXPElementId(long sxpElementId);

	/**
	 * Returns the company ID of this sxp element.
	 *
	 * @return the company ID of this sxp element
	 */
	@Override
	public long getCompanyId();

	/**
	 * Sets the company ID of this sxp element.
	 *
	 * @param companyId the company ID of this sxp element
	 */
	@Override
	public void setCompanyId(long companyId);

	/**
	 * Returns the user ID of this sxp element.
	 *
	 * @return the user ID of this sxp element
	 */
	@Override
	public long getUserId();

	/**
	 * Sets the user ID of this sxp element.
	 *
	 * @param userId the user ID of this sxp element
	 */
	@Override
	public void setUserId(long userId);

	/**
	 * Returns the user uuid of this sxp element.
	 *
	 * @return the user uuid of this sxp element
	 */
	@Override
	public String getUserUuid();

	/**
	 * Sets the user uuid of this sxp element.
	 *
	 * @param userUuid the user uuid of this sxp element
	 */
	@Override
	public void setUserUuid(String userUuid);

	/**
	 * Returns the user name of this sxp element.
	 *
	 * @return the user name of this sxp element
	 */
	@AutoEscape
	@Override
	public String getUserName();

	/**
	 * Sets the user name of this sxp element.
	 *
	 * @param userName the user name of this sxp element
	 */
	@Override
	public void setUserName(String userName);

	/**
	 * Returns the create date of this sxp element.
	 *
	 * @return the create date of this sxp element
	 */
	@Override
	public Date getCreateDate();

	/**
	 * Sets the create date of this sxp element.
	 *
	 * @param createDate the create date of this sxp element
	 */
	@Override
	public void setCreateDate(Date createDate);

	/**
	 * Returns the modified date of this sxp element.
	 *
	 * @return the modified date of this sxp element
	 */
	@Override
	public Date getModifiedDate();

	/**
	 * Sets the modified date of this sxp element.
	 *
	 * @param modifiedDate the modified date of this sxp element
	 */
	@Override
	public void setModifiedDate(Date modifiedDate);

	/**
	 * Returns the description of this sxp element.
	 *
	 * @return the description of this sxp element
	 */
	public String getDescription();

	/**
	 * Returns the localized description of this sxp element in the language. Uses the default language if no localization exists for the requested language.
	 *
	 * @param locale the locale of the language
	 * @return the localized description of this sxp element
	 */
	@AutoEscape
	public String getDescription(Locale locale);

	/**
	 * Returns the localized description of this sxp element in the language, optionally using the default language if no localization exists for the requested language.
	 *
	 * @param locale the local of the language
	 * @param useDefault whether to use the default language if no localization exists for the requested language
	 * @return the localized description of this sxp element. If <code>useDefault</code> is <code>false</code> and no localization exists for the requested language, an empty string will be returned.
	 */
	@AutoEscape
	public String getDescription(Locale locale, boolean useDefault);

	/**
	 * Returns the localized description of this sxp element in the language. Uses the default language if no localization exists for the requested language.
	 *
	 * @param languageId the ID of the language
	 * @return the localized description of this sxp element
	 */
	@AutoEscape
	public String getDescription(String languageId);

	/**
	 * Returns the localized description of this sxp element in the language, optionally using the default language if no localization exists for the requested language.
	 *
	 * @param languageId the ID of the language
	 * @param useDefault whether to use the default language if no localization exists for the requested language
	 * @return the localized description of this sxp element
	 */
	@AutoEscape
	public String getDescription(String languageId, boolean useDefault);

	@AutoEscape
	public String getDescriptionCurrentLanguageId();

	@AutoEscape
	public String getDescriptionCurrentValue();

	/**
	 * Returns a map of the locales and localized descriptions of this sxp element.
	 *
	 * @return the locales and localized descriptions of this sxp element
	 */
	public Map<Locale, String> getDescriptionMap();

	/**
	 * Sets the description of this sxp element.
	 *
	 * @param description the description of this sxp element
	 */
	public void setDescription(String description);

	/**
	 * Sets the localized description of this sxp element in the language.
	 *
	 * @param description the localized description of this sxp element
	 * @param locale the locale of the language
	 */
	public void setDescription(String description, Locale locale);

	/**
	 * Sets the localized description of this sxp element in the language, and sets the default locale.
	 *
	 * @param description the localized description of this sxp element
	 * @param locale the locale of the language
	 * @param defaultLocale the default locale
	 */
	public void setDescription(
		String description, Locale locale, Locale defaultLocale);

	public void setDescriptionCurrentLanguageId(String languageId);

	/**
	 * Sets the localized descriptions of this sxp element from the map of locales and localized descriptions.
	 *
	 * @param descriptionMap the locales and localized descriptions of this sxp element
	 */
	public void setDescriptionMap(Map<Locale, String> descriptionMap);

	/**
	 * Sets the localized descriptions of this sxp element from the map of locales and localized descriptions, and sets the default locale.
	 *
	 * @param descriptionMap the locales and localized descriptions of this sxp element
	 * @param defaultLocale the default locale
	 */
	public void setDescriptionMap(
		Map<Locale, String> descriptionMap, Locale defaultLocale);

	/**
	 * Returns the element definition json of this sxp element.
	 *
	 * @return the element definition json of this sxp element
	 */
	@AutoEscape
	public String getElementDefinitionJSON();

	/**
	 * Sets the element definition json of this sxp element.
	 *
	 * @param elementDefinitionJSON the element definition json of this sxp element
	 */
	public void setElementDefinitionJSON(String elementDefinitionJSON);

	/**
	 * Returns the hidden of this sxp element.
	 *
	 * @return the hidden of this sxp element
	 */
	public boolean getHidden();

	/**
	 * Returns <code>true</code> if this sxp element is hidden.
	 *
	 * @return <code>true</code> if this sxp element is hidden; <code>false</code> otherwise
	 */
	public boolean isHidden();

	/**
	 * Sets whether this sxp element is hidden.
	 *
	 * @param hidden the hidden of this sxp element
	 */
	public void setHidden(boolean hidden);

	/**
	 * Returns the read only of this sxp element.
	 *
	 * @return the read only of this sxp element
	 */
	public boolean getReadOnly();

	/**
	 * Returns <code>true</code> if this sxp element is read only.
	 *
	 * @return <code>true</code> if this sxp element is read only; <code>false</code> otherwise
	 */
	public boolean isReadOnly();

	/**
	 * Sets whether this sxp element is read only.
	 *
	 * @param readOnly the read only of this sxp element
	 */
	public void setReadOnly(boolean readOnly);

	/**
	 * Returns the schema version of this sxp element.
	 *
	 * @return the schema version of this sxp element
	 */
	@AutoEscape
	public String getSchemaVersion();

	/**
	 * Sets the schema version of this sxp element.
	 *
	 * @param schemaVersion the schema version of this sxp element
	 */
	public void setSchemaVersion(String schemaVersion);

	/**
	 * Returns the title of this sxp element.
	 *
	 * @return the title of this sxp element
	 */
	public String getTitle();

	/**
	 * Returns the localized title of this sxp element in the language. Uses the default language if no localization exists for the requested language.
	 *
	 * @param locale the locale of the language
	 * @return the localized title of this sxp element
	 */
	@AutoEscape
	public String getTitle(Locale locale);

	/**
	 * Returns the localized title of this sxp element in the language, optionally using the default language if no localization exists for the requested language.
	 *
	 * @param locale the local of the language
	 * @param useDefault whether to use the default language if no localization exists for the requested language
	 * @return the localized title of this sxp element. If <code>useDefault</code> is <code>false</code> and no localization exists for the requested language, an empty string will be returned.
	 */
	@AutoEscape
	public String getTitle(Locale locale, boolean useDefault);

	/**
	 * Returns the localized title of this sxp element in the language. Uses the default language if no localization exists for the requested language.
	 *
	 * @param languageId the ID of the language
	 * @return the localized title of this sxp element
	 */
	@AutoEscape
	public String getTitle(String languageId);

	/**
	 * Returns the localized title of this sxp element in the language, optionally using the default language if no localization exists for the requested language.
	 *
	 * @param languageId the ID of the language
	 * @param useDefault whether to use the default language if no localization exists for the requested language
	 * @return the localized title of this sxp element
	 */
	@AutoEscape
	public String getTitle(String languageId, boolean useDefault);

	@AutoEscape
	public String getTitleCurrentLanguageId();

	@AutoEscape
	public String getTitleCurrentValue();

	/**
	 * Returns a map of the locales and localized titles of this sxp element.
	 *
	 * @return the locales and localized titles of this sxp element
	 */
	public Map<Locale, String> getTitleMap();

	/**
	 * Sets the title of this sxp element.
	 *
	 * @param title the title of this sxp element
	 */
	public void setTitle(String title);

	/**
	 * Sets the localized title of this sxp element in the language.
	 *
	 * @param title the localized title of this sxp element
	 * @param locale the locale of the language
	 */
	public void setTitle(String title, Locale locale);

	/**
	 * Sets the localized title of this sxp element in the language, and sets the default locale.
	 *
	 * @param title the localized title of this sxp element
	 * @param locale the locale of the language
	 * @param defaultLocale the default locale
	 */
	public void setTitle(String title, Locale locale, Locale defaultLocale);

	public void setTitleCurrentLanguageId(String languageId);

	/**
	 * Sets the localized titles of this sxp element from the map of locales and localized titles.
	 *
	 * @param titleMap the locales and localized titles of this sxp element
	 */
	public void setTitleMap(Map<Locale, String> titleMap);

	/**
	 * Sets the localized titles of this sxp element from the map of locales and localized titles, and sets the default locale.
	 *
	 * @param titleMap the locales and localized titles of this sxp element
	 * @param defaultLocale the default locale
	 */
	public void setTitleMap(Map<Locale, String> titleMap, Locale defaultLocale);

	/**
	 * Returns the type of this sxp element.
	 *
	 * @return the type of this sxp element
	 */
	public int getType();

	/**
	 * Sets the type of this sxp element.
	 *
	 * @param type the type of this sxp element
	 */
	public void setType(int type);

	/**
	 * Returns the status of this sxp element.
	 *
	 * @return the status of this sxp element
	 */
	public int getStatus();

	/**
	 * Sets the status of this sxp element.
	 *
	 * @param status the status of this sxp element
	 */
	public void setStatus(int status);

	@Override
	public String[] getAvailableLanguageIds();

	@Override
	public String getDefaultLanguageId();

	@Override
	public void prepareLocalizedFieldsForImport() throws LocaleException;

	@Override
	public void prepareLocalizedFieldsForImport(Locale defaultImportLocale)
		throws LocaleException;

	@Override
	public SXPElement cloneWithOriginalValues();

}